import json
from typing import Any, Dict, List, Type, TypeVar

import attr

from .deployment_complete import DeploymentComplete

T = TypeVar("T", bound="DeploymentList")


@attr.s(auto_attribs=True, repr=False)
class DeploymentList:
    """
    Attributes:
        total_pages (int):
        deployments (List[DeploymentComplete]):
    """

    total_pages: int
    deployments: List[DeploymentComplete]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total_pages = self.total_pages
        deployments = []
        for deployments_item_data in self.deployments:
            deployments_item = deployments_item_data.to_dict()

            deployments.append(deployments_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "total_pages": total_pages,
                "deployments": deployments,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        total_pages = d.pop("total_pages")

        deployments = []
        _deployments = d.pop("deployments")
        for deployments_item_data in _deployments:
            deployments_item = DeploymentComplete.from_dict(deployments_item_data)

            deployments.append(deployments_item)

        deployment_list = cls(
            total_pages=total_pages,
            deployments=deployments,
        )

        deployment_list.additional_properties = d
        return deployment_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.repo import Repo
from ..types import UNSET, Unset

T = TypeVar("T", bound="VCSRepoResponse")


@attr.s(auto_attribs=True, repr=False)
class VCSRepoResponse:
    """
    Attributes:
        repos (Union[Unset, List[Repo]]):
        total_pages (Union[Unset, int]):
        message (Union[Unset, str]):  Default: ''.
    """

    repos: Union[Unset, List[Repo]] = UNSET
    total_pages: Union[Unset, int] = 0
    message: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        repos: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.repos, Unset):
            repos = []
            for repos_item_data in self.repos:
                repos_item = repos_item_data.to_dict()

                repos.append(repos_item)

        total_pages = self.total_pages
        message = self.message

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if repos is not UNSET:
            field_dict["repos"] = repos
        if total_pages is not UNSET:
            field_dict["total_pages"] = total_pages
        if message is not UNSET:
            field_dict["message"] = message

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        repos = []
        _repos = d.pop("repos", UNSET)
        for repos_item_data in _repos or []:
            repos_item = Repo.from_dict(repos_item_data)

            repos.append(repos_item)

        total_pages = d.pop("total_pages", UNSET)

        message = d.pop("message", UNSET)

        vcs_repo_response = cls(
            repos=repos,
            total_pages=total_pages,
            message=message,
        )

        vcs_repo_response.additional_properties = d
        return vcs_repo_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Instance")


@attr.s(auto_attribs=True, repr=False)
class Instance:
    """
    Attributes:
        region_name (Union[Unset, str]):  Default: ''.
        stack_name (Union[Unset, str]):  Default: ''.
        instance_type (Union[Unset, str]):  Default: ''.
        instance_url (Union[Unset, str]):  Default: ''.
        service_url (Union[Unset, str]):  Default: ''.
        build_log_location (Union[Unset, str]):  Default: ''.
    """

    region_name: Union[Unset, str] = ""
    stack_name: Union[Unset, str] = ""
    instance_type: Union[Unset, str] = ""
    instance_url: Union[Unset, str] = ""
    service_url: Union[Unset, str] = ""
    build_log_location: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        region_name = self.region_name
        stack_name = self.stack_name
        instance_type = self.instance_type
        instance_url = self.instance_url
        service_url = self.service_url
        build_log_location = self.build_log_location

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if region_name is not UNSET:
            field_dict["region_name"] = region_name
        if stack_name is not UNSET:
            field_dict["stack_name"] = stack_name
        if instance_type is not UNSET:
            field_dict["instance_type"] = instance_type
        if instance_url is not UNSET:
            field_dict["instance_url"] = instance_url
        if service_url is not UNSET:
            field_dict["service_url"] = service_url
        if build_log_location is not UNSET:
            field_dict["build_log_location"] = build_log_location

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        region_name = d.pop("region_name", UNSET)

        stack_name = d.pop("stack_name", UNSET)

        instance_type = d.pop("instance_type", UNSET)

        instance_url = d.pop("instance_url", UNSET)

        service_url = d.pop("service_url", UNSET)

        build_log_location = d.pop("build_log_location", UNSET)

        instance = cls(
            region_name=region_name,
            stack_name=stack_name,
            instance_type=instance_type,
            instance_url=instance_url,
            service_url=service_url,
            build_log_location=build_log_location,
        )

        instance.additional_properties = d
        return instance

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, cast

import attr

from .deployment_complete import DeploymentComplete

T = TypeVar("T", bound="AvailableDeployment")


@attr.s(auto_attribs=True, repr=False)
class AvailableDeployment:
    """
    Attributes:
        role (List[str]):
        deployment (DeploymentComplete):
    """

    role: List[str]
    deployment: DeploymentComplete
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        role = self.role

        deployment = self.deployment.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "role": role,
                "deployment": deployment,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        role = cast(List[str], d.pop("role"))

        deployment = DeploymentComplete.from_dict(d.pop("deployment"))

        available_deployment = cls(
            role=role,
            deployment=deployment,
        )

        available_deployment.additional_properties = d
        return available_deployment

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json

import typer

from . import utils

app = typer.Typer()


@app.command(help="To create a new service")
def create(repo_owner: str = typer.Argument(..., help=("Repository Owner")), repo_name: str = typer.Argument(...,help=("Repository Name")), ref: str = typer.Argument(..., help=("Service ref name")), tag : bool = typer.Option(False, "--tag",help="If provided, the ref is considered to be a tag on repository"), service_file : str = typer.Option(None,help="Service yaml file in json format. Not allowed with --tag")):
    try:
        client = utils.read_credentials()
        if tag:
            client.add_service(repo_owner=repo_owner,repo_name=repo_name,ref=ref,ref_type="tag")
        else:
            args = {}
            if service_file!=None:
                with open(service_file,"r") as f:
                    args = json.load(f)
            client.add_service(repo_owner=repo_owner,repo_name=repo_name,ref=ref, data=args)
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
        pass
    else:
        utils.render_success_message("Added the service")

@app.command(help="To remove an existing service")
def remove(repo_owner: str = typer.Argument(..., help=("Repository Owner")), repo_name: str = typer.Argument(...,help=("Repository Name")), ref: str = typer.Argument(..., help=("Service ref name")), tag : bool = typer.Option(False, "--tag", help="If provided, the ref is considered to be a tag on repository")):
    try:
        client = utils.read_credentials()
        if tag:
            client.remove_service(repo_owner=repo_owner,repo_name=repo_name,ref=ref,ref_type="tag")
        else:
            client.remove_service(repo_owner=repo_owner,repo_name=repo_name,ref=ref)
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
        pass
    else:
        utils.render_success_message("Removed the service")

@app.command(help="To fetch user's services list")
def fetch():
    try:
        client = utils.read_credentials()
        utils.render_output(client.user_services())
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
        pass

@app.command(help="To updates user's service")
def update(repo_owner: str = typer.Argument(..., help=("Repository Owner")), repo_name: str = typer.Argument(...,help=("Repository Name")), ref: str = typer.Argument(..., help=("Service ref name")), tag : bool = typer.Option(False, "--tag", help="If provided, the ref is considered to be a tag on repository"), service_file : str = typer.Option(None,help="Service yaml file in json format. Not allowed with --tag")):
    try:
        client = utils.read_credentials()
        if tag:
            client.update_service(repo_owner=repo_owner,repo_name=repo_name,ref=ref,ref_type="tag")
        else:
            args = {}
            if service_file!=None:
                with open(service_file,"r") as f:
                    args = json.load(f)
            client.update_service(repo_owner=repo_owner,repo_name=repo_name,ref=ref, data=args)
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
        pass
    else:
        utils.render_success_message("Updated the service")






class bcolors:
    HEADER = "\033[95m"
    BLUE = "\033[94m"
    GREEN = "\033[92m"
    YELLOW = "\033[93m"
    RED = "\033[91m"
    ENDC = "\033[0m"
    BOLD = "\033[1m"
    UNDERLINE = "\033[4m"
    BLACK = "\033[99m"

    @staticmethod
    def green(message: str) -> str:
        return bcolors.GREEN + message + bcolors.ENDC

    @staticmethod
    def red(message: str) -> str:
        return bcolors.RED + message + bcolors.ENDC

    @staticmethod
    def yellow(message: str) -> str:
        return bcolors.YELLOW + message + bcolors.ENDC

    @staticmethod
    def bold(message: str, end_color: bool = False) -> str:
        msg = bcolors.BOLD + message
        if end_color:
            msg += bcolors.ENDC
        return msg

    @staticmethod
    def underline(message: str, end_color: bool = False) -> str:
        msg = bcolors.UNDERLINE + message
        if end_color:
            msg += bcolors.ENDC
        return msg

    @staticmethod
    def warning(message: str) -> str:
        return bcolors.bold(bcolors.yellow(message))

    @staticmethod
    def success(message: str) -> str:
        return bcolors.green(message)

    @staticmethod
    def failure(message: str) -> str:
        return bcolors.red(message)


import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationResponse")


@attr.s(auto_attribs=True, repr=False)
class NotificationResponse:
    """
    Attributes:
        id (Union[Unset, str]):  Default: ''.
        summary (Union[Unset, str]):  Default: ''.
        type (Union[Unset, str]):  Default: ''.
        description (Union[Unset, str]):  Default: ''.
        created_at (Union[Unset, str]):  Default: ''.
        seen (Union[Unset, bool]):
    """

    id: Union[Unset, str] = ""
    summary: Union[Unset, str] = ""
    type: Union[Unset, str] = ""
    description: Union[Unset, str] = ""
    created_at: Union[Unset, str] = ""
    seen: Union[Unset, bool] = False
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        summary = self.summary
        type = self.type
        description = self.description
        created_at = self.created_at
        seen = self.seen

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if summary is not UNSET:
            field_dict["summary"] = summary
        if type is not UNSET:
            field_dict["type"] = type
        if description is not UNSET:
            field_dict["description"] = description
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if seen is not UNSET:
            field_dict["seen"] = seen

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        summary = d.pop("summary", UNSET)

        type = d.pop("type", UNSET)

        description = d.pop("description", UNSET)

        created_at = d.pop("created_at", UNSET)

        seen = d.pop("seen", UNSET)

        notification_response = cls(
            id=id,
            summary=summary,
            type=type,
            description=description,
            created_at=created_at,
            seen=seen,
        )

        notification_response.additional_properties = d
        return notification_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserProfileResponse")


@attr.s(auto_attribs=True, repr=False)
class UserProfileResponse:
    """
    Attributes:
        oblivious_login (Union[Unset, str]):  Default: ''.
        email (Union[Unset, str]):  Default: ''.
        user_name (Union[Unset, str]):  Default: ''.
        public_key (Union[Unset, str]):  Default: ''.
    """

    oblivious_login: Union[Unset, str] = ""
    email: Union[Unset, str] = ""
    user_name: Union[Unset, str] = ""
    public_key: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        oblivious_login = self.oblivious_login
        email = self.email
        user_name = self.user_name
        public_key = self.public_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if oblivious_login is not UNSET:
            field_dict["oblivious_login"] = oblivious_login
        if email is not UNSET:
            field_dict["email"] = email
        if user_name is not UNSET:
            field_dict["user_name"] = user_name
        if public_key is not UNSET:
            field_dict["public_key"] = public_key

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        oblivious_login = d.pop("oblivious_login", UNSET)

        email = d.pop("email", UNSET)

        user_name = d.pop("user_name", UNSET)

        public_key = d.pop("public_key", UNSET)

        user_profile_response = cls(
            oblivious_login=oblivious_login,
            email=email,
            user_name=user_name,
            public_key=public_key,
        )

        user_profile_response.additional_properties = d
        return user_profile_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import json
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserCreditUtilization")


@attr.s(auto_attribs=True, repr=False)
class UserCreditUtilization:
    """
    Attributes:
        total_credits (Union[Unset, int]):
        total_running_deployments (Union[Unset, int]):
        esitmated_hours_remaining (Union[Unset, int]):
        hourly_credit_utilization (Union[Unset, int]):
    """

    total_credits: Union[Unset, int] = 0
    total_running_deployments: Union[Unset, int] = 0
    esitmated_hours_remaining: Union[Unset, int] = 0
    hourly_credit_utilization: Union[Unset, int] = 0
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total_credits = self.total_credits
        total_running_deployments = self.total_running_deployments
        esitmated_hours_remaining = self.esitmated_hours_remaining
        hourly_credit_utilization = self.hourly_credit_utilization

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total_credits is not UNSET:
            field_dict["total_credits"] = total_credits
        if total_running_deployments is not UNSET:
            field_dict["total_running_deployments"] = total_running_deployments
        if esitmated_hours_remaining is not UNSET:
            field_dict["esitmated_hours_remaining"] = esitmated_hours_remaining
        if hourly_credit_utilization is not UNSET:
            field_dict["hourly_credit_utilization"] = hourly_credit_utilization

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        total_credits = d.pop("total_credits", UNSET)

        total_running_deployments = d.pop("total_running_deployments", UNSET)

        esitmated_hours_remaining = d.pop("esitmated_hours_remaining", UNSET)

        hourly_credit_utilization = d.pop("hourly_credit_utilization", UNSET)

        user_credit_utilization = cls(
            total_credits=total_credits,
            total_running_deployments=total_running_deployments,
            esitmated_hours_remaining=esitmated_hours_remaining,
            hourly_credit_utilization=hourly_credit_utilization,
        )

        user_credit_utilization.additional_properties = d
        return user_credit_utilization

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import os

from rich.console import Console

from oblv_ctl import OblvClient

from ..utils import bcolors

cred_file_path = os.path.join(os.path.expanduser('~'),'.oblv','credentials')

console = Console()

NO_CREDS_FOUND = "No credentials found"

def read_credentials():
    with open(cred_file_path,'r') as f:
        contents = f.read()
        if not contents:
            raise Exception("No credentials found")
        contents = contents.split("\n")
        for c in range(2):
            contents[c]=contents[c].split(" = ")
        client = OblvClient(oblivious_user_id=contents[0][1],token=contents[1][1])
    return client


def render_output(object):
    if type(object)==list:
        console.print_json(data=[x.to_dict() for x in object])
    else:
        console.print_json(data=object.to_dict())
        
def render_success_message(message: str):
    print(
                bcolors.GREEN
                + "Success"
                + bcolors.BLACK
                + bcolors.ENDC
                + f": {message}",
            )
    
def render_warning_message(message: str):
    print(
                bcolors.YELLOW
                + "WARNING"
                + bcolors.BLACK
                + bcolors.ENDC
                + f": {message}",
            )
    
def render_error_message(message: str):
    print(
                bcolors.RED
                + "ERROR"
                + bcolors.BLACK
                + bcolors.ENDC
                + f": {message}",
            )

def render_info_message(message: str):
    print(
                bcolors.BLUE
                + "INFO"
                + bcolors.BLACK
                + bcolors.ENDC
                + f": {message}",
            )



import json
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.validated_service import ValidatedService
from ..types import UNSET, Unset

T = TypeVar("T", bound="RepoServiceList")


@attr.s(auto_attribs=True, repr=False)
class RepoServiceList:
    """
    Attributes:
        total_pages (int):
        services (List[ValidatedService]):
    """

    total_pages: int
    services: List[ValidatedService]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total_pages = self.total_pages
        services = []
        for services_item_data in self.services:
            services_item = services_item_data.to_dict()

            services.append(services_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "total_pages": total_pages,
                "services": services,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        total_pages = d.pop("total_pages")

        services = []
        _services = d.pop("services")
        for services_item_data in _services:
            services_item = ValidatedService.from_dict(services_item_data)

            services.append(services_item)

        repo_services_list = cls(
            total_pages=total_pages,
            services=services,
        )

        repo_services_list.additional_properties = d
        return repo_services_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)



import enum
import json

import typer

from oblv_ctl.models.create_deployment_input import CreateDeploymentInput

from . import utils

app = typer.Typer()

regions = ["us-east-1","us-west-2","eu-central-1","eu-west-2"]

class reg(enum.Enum):
    N_Virginia ="us-east-1"
    Oregon ="us-west-2"
    Frankfurt= "eu-central-1"
    London = "eu-west-2"

@app.command(help="To create a deployment")
def create(repo_owner: str = typer.Argument(..., help=("Repository Owner")), repo_name: str = typer.Argument(..., help=("Repository Name")), ref: str = typer.Argument(..., help=("Service ref name")), name: str = typer.Argument(..., help=("Deployment Name")), public: bool = typer.Option(False, "--public", help="If provided, the deployment is made public"), is_dev: bool = typer.Option(False, "--is-dev", help="Sets the environment of the deployment as DEV"),region: reg = typer.Option("us-east-1",help="Region where enclave will be deployed. The options include [\"us-east-1\" (N. Virginia),  \"us-west-2\" (Oregon), \"eu-central-1\" (Frankfurt), \"eu-west-2\" (London)]"),args_file : str = typer.Option(None,help="arguments file path for enclave deployment")):
    try:
        client = utils.read_credentials()
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
    try:
        visibility = "public" if public else "private"
        if args_file==None:
            args_file = typer.prompt("Provide the arguments file for enclave deployment ")
        with open(args_file,"r") as f:
            args = json.load(f)
    except FileNotFoundError as e:
        utils.render_error_message("Could not find the arguments file at \""+args_file+"\"")
    except Exception as e:
        utils.render_error_message(str(e))
    try:
        input = CreateDeploymentInput(repo_owner,repo_name,"github",ref,region._value_,name,visibility,is_dev,[],args)
        res = client.create_deployment(input)
        utils.render_success_message("Deployment created with id - {}".format(res.deployment_id))
    except Exception as e:
        pass

@app.command(help="To terminate a deployment")
def terminate(deployment_id: str = typer.Argument(...,help="Deployment Id to terminate")):
    try:
        client = utils.read_credentials()
        client.remove_deployment(deployment_id)
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
    else:
        utils.render_info_message("Terminating deployment with id {}".format(deployment_id))

@app.command(help="To get the deployment information.\n\nIf no option is provided, complete information of the deployment is shown")
def info(deployment_id: str = typer.Argument(...,help="Deployment Id for which information is requested"),state: bool = typer.Option(False,"--state",help="To get the current state of deployment"),instance: bool = typer.Option(False,"--instance",help="To get the instance info of deployment"),pcrs: bool = typer.Option(False,"--pcrs",help="To get the pcrs of deployment")):
    try:
        client = utils.read_credentials()
        depl = client.deployment_info(deployment_id)
        if not state and not instance and not pcrs:
            utils.render_output(depl)
        else:
            resp = {}
            if state:
                resp["state"]=depl.current_state
            if pcrs:
                resp["pcr_codes"]=depl.pcr_codes
            if instance:
                resp["instance"]=depl.instance
            utils.render_output(resp)
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")
        
@app.command(help="To get the owned deployments")
def owned():
    try:
        client = utils.read_credentials()
        depl_l = client.deployments()
        depl = []
        for d in depl_l if depl_l != None else []:
            depl.append({
                "deployment_id": d.deployment_id,
                "deployment_name": d.deployment_name
            })
        utils.render_output(depl)
    except FileNotFoundError as e:
        utils.render_warning_message("Kindly login before performing this action")
    except Exception as e:
        if e.args[0]==utils.NO_CREDS_FOUND:
            utils.render_warning_message("Kindly login before performing this action")



from oblv_ctl.exceptions import BadRequestError
from .oblv_client import OblvClient
from .api.auth import authenticate_key_login_apikey_post
from .models import APIKey
from .client import Client

def authenticate(apikey: str):
    response = authenticate_key_login_apikey_post.sync(client=Client(), json_body=APIKey(apikey))
    return OblvClient(response.token,response.user_id)



import json
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SharedUsers")


@attr.s(auto_attribs=True, repr=False)
class SharedUsers:
    """
    Attributes:
        role (List[str]):
        oblivious_user_id (Union[Unset, str]):  Default: ''.
        use_case (Union[Unset, str]):  Default: ''.
        oblivious_login (Union[Unset, str]):  Default: ''.
    """

    role: List[str]
    oblivious_user_id: Union[Unset, str] = ""
    use_case: Union[Unset, str] = ""
    oblivious_login: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        role = self.role

        oblivious_user_id = self.oblivious_user_id
        use_case = self.use_case
        oblivious_login = self.oblivious_login

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "role": role,
            }
        )
        if oblivious_user_id is not UNSET:
            field_dict["oblivious_user_id"] = oblivious_user_id
        if use_case is not UNSET:
            field_dict["use_case"] = use_case
        if oblivious_login is not UNSET:
            field_dict["oblivious_login"] = oblivious_login

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        role = cast(List[str], d.pop("role"))

        oblivious_user_id = d.pop("oblivious_user_id", UNSET)

        use_case = d.pop("use_case", UNSET)

        oblivious_login = d.pop("oblivious_login", UNSET)

        shared_users = cls(
            role=role,
            oblivious_user_id=oblivious_user_id,
            use_case=use_case,
            oblivious_login=oblivious_login,
        )

        shared_users.additional_properties = d
        return shared_users

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

    def __str__(self):
        return json.dumps(self.to_dict(), indent=2)

    def __repr__(self):
        return str(self)
